@@ -9,14 +9,18 @@ import re
 import sys
 from collections import ChainMap
 from contextlib import suppress
+from pathlib import Path
 from typing import TYPE_CHECKING, Any, BinaryIO, ClassVar, Iterator, Mapping, Sequence
 
-from griffe.collections import LinesCollection, ModulesCollection
-from griffe.docstrings.parsers import Parser
-from griffe.exceptions import AliasResolutionError
-from griffe.extensions import load_extensions
-from griffe.loader import GriffeLoader
-from griffe.logger import patch_loggers
+from griffe import (
+    AliasResolutionError,
+    GriffeLoader,
+    LinesCollection,
+    ModulesCollection,
+    Parser,
+    load_extensions,
+    patch_logger,
+)
 from mkdocstrings.extension import PluginError
 from mkdocstrings.handlers.base import BaseHandler, CollectionError, CollectorItem
 from mkdocstrings.inventory import Inventory
@@ -46,29 +50,28 @@ else:
 
 logger = get_logger(__name__)
 
-patch_loggers(get_logger)
+patch_logger(get_logger)
 
 
 class PythonHandler(BaseHandler):
-    """The Python handler class.
-
-    Attributes:
-        domain: The cross-documentation domain/language for this handler.
-        enable_inventory: Whether this handler is interested in enabling the creation
-            of the `objects.inv` Sphinx inventory file.
-        fallback_theme: The fallback theme.
-        fallback_config: The configuration used to collect item during autorefs fallback.
-        default_config: The default rendering options,
-            see [`default_config`][mkdocstrings_handlers.python.handler.PythonHandler.default_config].
-    """
+    """The Python handler class."""
 
+    name: str = "python"
+    """The handler's name."""
     domain: str = "py"  # to match Sphinx's default domain
+    """The cross-documentation domain/language for this handler."""
     enable_inventory: bool = True
+    """Whether this handler is interested in enabling the creation of the `objects.inv` Sphinx inventory file."""
     fallback_theme = "material"
+    """The fallback theme."""
     fallback_config: ClassVar[dict] = {"fallback": True}
+    """The configuration used to collect item during autorefs fallback."""
     default_config: ClassVar[dict] = {
+        "find_stubs_package": False,
         "docstring_style": "google",
         "docstring_options": {},
+        "show_symbol_type_heading": False,
+        "show_symbol_type_toc": False,
         "show_root_heading": False,
         "show_root_toc_entry": True,
         "show_root_full_path": True,
@@ -108,10 +111,14 @@ class PythonHandler(BaseHandler):
         "annotations_path": "brief",
         "preload_modules": None,
         "allow_inspection": True,
+        "summary": False,
+        "show_labels": True,
         "unwrap_annotated": False,
     }
-    """
+    """Default handler configuration.
+
     Attributes: General options:
+        find_stubs_package (bool): Whether to load stubs package (package-stubs) when extracting docstrings. Default `False`.
         allow_inspection (bool): Whether to allow inspecting modules when visiting them is not possible. Default: `True`.
         show_bases (bool): Show the base classes of a class. Default: `True`.
         show_source (bool): Show the source code of this object. Default: `True`.
@@ -134,6 +141,8 @@ class PythonHandler(BaseHandler):
         show_root_members_full_path (bool): Show the full Python path of the root members. Default: `False`.
         show_object_full_path (bool): Show the full Python path of every object. Default: `False`.
         show_category_heading (bool): When grouped by categories, show a heading for each category. Default: `False`.
+        show_symbol_type_heading (bool): Show the symbol type in headings (e.g. mod, class, meth, func and attr). Default: `False`.
+        show_symbol_type_toc (bool): Show the symbol type in the Table of Contents (e.g. mod, class, methd, func and attr). Default: `False`.
 
     Attributes: Members options:
         inherited_members (list[str] | bool | None): A boolean, or an explicit list of inherited members to render.
@@ -151,10 +160,12 @@ class PythonHandler(BaseHandler):
             to lower members in the hierarchy). Default: `["!^_[^_]"]`.
         group_by_category (bool): Group the object's children by categories: attributes, classes, functions, and modules. Default: `True`.
         show_submodules (bool): When rendering a module, show its submodules recursively. Default: `False`.
+        summary (bool | dict[str, bool]): Whether to render summaries of modules, classes, functions (methods) and attributes.
+        show_labels (bool): Whether to show labels of the members. Default: `True`.
 
     Attributes: Docstrings options:
         docstring_style (str): The docstring style to use: `google`, `numpy`, `sphinx`, or `None`. Default: `"google"`.
-        docstring_options (dict): The options for the docstring parser. See parsers under [`griffe.docstrings`][].
+        docstring_options (dict): The options for the docstring parser. See [docstring parsers](https://mkdocstrings.github.io/griffe/reference/docstrings/) and their options in Griffe docs.
         docstring_section_style (str): The style used to render docstring sections. Options: `table`, `list`, `spacy`. Default: `"table"`.
         merge_init_into_class (bool): Whether to merge the `__init__` method into the class' signature and docstring. Default: `False`.
         show_if_no_docstring (bool): Show the object heading even if it has no docstring or children with docstrings. Default: `False`.
@@ -189,7 +200,7 @@ class PythonHandler(BaseHandler):
         config_file_path: str | None = None,
         paths: list[str] | None = None,
         locale: str = "en",
-        load_external_modules: bool = False,
+        load_external_modules: bool | None = None,
         **kwargs: Any,
     ) -> None:
         """Initialize the handler.
@@ -203,21 +214,42 @@ class PythonHandler(BaseHandler):
             **kwargs: Same thing, but with keyword arguments.
         """
         super().__init__(*args, **kwargs)
+
+        # Warn if user overrides base templates.
+        if custom_templates := kwargs.get("custom_templates", ()):
+            config_dir = Path(config_file_path or "./mkdocs.yml").parent
+            for theme_dir in config_dir.joinpath(custom_templates, "python").iterdir():
+                if theme_dir.joinpath("_base").is_dir():
+                    logger.warning(
+                        f"Overriding base template '{theme_dir.name}/_base/<template>.html.jinja' is not supported, "
+                        f"override '{theme_dir.name}/<template>.html.jinja' instead",
+                    )
+
         self._config_file_path = config_file_path
         self._load_external_modules = load_external_modules
         paths = paths or []
+
+        # Expand paths with glob patterns.
         glob_base_dir = os.path.dirname(os.path.abspath(config_file_path)) if config_file_path else "."
         with chdir(glob_base_dir):
             resolved_globs = [glob.glob(path) for path in paths]
         paths = [path for glob_list in resolved_globs for path in glob_list]
+
+        # By default, add the directory of the config file to the search paths.
         if not paths and config_file_path:
             paths.append(os.path.dirname(config_file_path))
-        search_paths = [path for path in sys.path if path]  # eliminate empty path
+
+        # Initialize search paths from `sys.path`, eliminating empty paths.
+        search_paths = [path for path in sys.path if path]
+
         for path in reversed(paths):
+            # If it's not absolute, make path relative to the config file path, then make it absolute.
             if not os.path.isabs(path) and config_file_path:
                 path = os.path.abspath(os.path.join(os.path.dirname(config_file_path), path))  # noqa: PLW2901
+            # Don't add duplicates.
             if path not in search_paths:
                 search_paths.insert(0, path)
+
         self._paths = search_paths
         self._modules_collection: ModulesCollection = ModulesCollection()
         self._lines_collection: LinesCollection = LinesCollection()
@@ -267,7 +299,7 @@ class PythonHandler(BaseHandler):
         if unknown_module:
             extensions = self.normalize_extension_paths(final_config.get("extensions", []))
             loader = GriffeLoader(
-                extensions=load_extensions(extensions),
+                extensions=load_extensions(*extensions),
                 search_paths=self._paths,
                 docstring_parser=parser,
                 docstring_options=parser_options,
@@ -278,8 +310,16 @@ class PythonHandler(BaseHandler):
             try:
                 for pre_loaded_module in final_config.get("preload_modules") or []:
                     if pre_loaded_module not in self._modules_collection:
-                        loader.load(pre_loaded_module)
-                loader.load(module_name)
+                        loader.load(
+                            pre_loaded_module,
+                            try_relative_path=False,
+                            find_stubs_package=final_config["find_stubs_package"],
+                        )
+                loader.load(
+                    module_name,
+                    try_relative_path=False,
+                    find_stubs_package=final_config["find_stubs_package"],
+                )
             except ImportError as error:
                 raise CollectionError(str(error)) from error
             unresolved, iterations = loader.resolve_aliases(
@@ -308,7 +348,7 @@ class PythonHandler(BaseHandler):
     def render(self, data: CollectorItem, config: Mapping[str, Any]) -> str:  # noqa: D102 (ignore missing docstring)
         final_config = ChainMap(config, self.default_config)  # type: ignore[arg-type]
 
-        template_name = rendering.do_get_template(data)
+        template_name = rendering.do_get_template(self.env, data)
         template = self.env.get_template(template_name)
 
         # Heading level is a "state" variable, that will change at each step
@@ -328,8 +368,28 @@ class PythonHandler(BaseHandler):
                 (re.compile(filtr.lstrip("!")), filtr.startswith("!")) for filtr in final_config["filters"]
             ]
 
-        # TODO: goal reached: remove once `signature_crossrefs` feature becomes public
-        final_config["signature_crossrefs"] = False
+        summary = final_config["summary"]
+        if summary is True:
+            final_config["summary"] = {
+                "attributes": True,
+                "functions": True,
+                "classes": True,
+                "modules": True,
+            }
+        elif summary is False:
+            final_config["summary"] = {
+                "attributes": False,
+                "functions": False,
+                "classes": False,
+                "modules": False,
+            }
+        else:
+            final_config["summary"] = {
+                "attributes": summary.get("attributes", False),
+                "functions": summary.get("functions", False),
+                "classes": summary.get("classes", False),
+                "modules": summary.get("modules", False),
+            }
 
         return template.render(
             **{
@@ -341,7 +401,13 @@ class PythonHandler(BaseHandler):
             },
         )
 
-    def update_env(self, md: Markdown, config: dict) -> None:  # noqa: D102 (ignore missing docstring)
+    def update_env(self, md: Markdown, config: dict) -> None:
+        """Update the Jinja environment with custom filters and tests.
+
+        Parameters:
+            md: The Markdown instance.
+            config: The configuration dictionary.
+        """
         super().update_env(md, config)
         self.env.trim_blocks = True
         self.env.lstrip_blocks = True
@@ -356,6 +422,10 @@ class PythonHandler(BaseHandler):
         self.env.filters["filter_objects"] = rendering.do_filter_objects
         self.env.filters["stash_crossref"] = lambda ref, length: ref
         self.env.filters["get_template"] = rendering.do_get_template
+        self.env.filters["as_attributes_section"] = rendering.do_as_attributes_section
+        self.env.filters["as_functions_section"] = rendering.do_as_functions_section
+        self.env.filters["as_classes_section"] = rendering.do_as_classes_section
+        self.env.filters["as_modules_section"] = rendering.do_as_modules_section
         self.env.tests["existing_template"] = lambda template_name: template_name in self.env.list_templates()
 
     def get_anchors(self, data: CollectorItem) -> tuple[str, ...]:  # noqa: D102 (ignore missing docstring)
@@ -407,7 +477,7 @@ def get_handler(
     config_file_path: str | None = None,
     paths: list[str] | None = None,
     locale: str = "en",
-    load_external_modules: bool = False,
+    load_external_modules: bool | None = None,
     **config: Any,  # noqa: ARG001
 ) -> PythonHandler:
     """Simply return an instance of `PythonHandler`.
